pub enum RemoveIndices {
Single(usize),
Multiple(Vec<usize>),
}Expand description
An enum to represent whether a single index or multiple indices should be removed.
This is used in the remove method of RankedFeatureList.
Fields
Single(usize): Remove a single indexMultiple(Vec<usize>): Remove multiple indices
Examples
use dual_threshold_optimization::collections::RemoveIndices;
let single_index = RemoveIndices::Single(5);
let multiple_indices = RemoveIndices::Multiple(vec![1, 2, 3]);Variants